@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3067 2010-04-24 08:56:38Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3146 2010-05-19 03:27:11Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -39,9 +39,8 @@ class ScriptLibInfo
 	
 	// Javascriptライブラリ用のファイル
 	const JQUERY_EASING_FILENAME		= 'jquery/jquery.easing.1.3.js';
-	//const JQUERY_JCAROUSEL_FILENAME	= 'jquery/jquery.jcarousel.pack.js';
-	const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.3.pack_fixed.js';
-	const JQUERY_JCAROUSEL_CSS			= 'jquery/jquery.jcarousel.css';
+	//const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.3.pack_fixed.js';
+	const JQUERY_JCAROUSEL_FILENAME		= 'jquery/jquery.jcarousel.0.2.4.min.js';		// jQuery1.4.2対応版
 	const JQUERY_CONTEXTMENU_FILENAME	= 'jquery/jquery.contextmenu.r2.packed.js';
 	const JQUERY_THICKBOX_FILENAME		= 'jquery/thickbox-compressed.js';
 	const JQUERY_THICKBOX_CSS			= 'jquery/thickbox.css';
@@ -93,8 +92,7 @@ class ScriptLibInfo
 					self::LIB_JQUERY_UI				=>	array(	'script' => array(self::JQUERY_UI_CORE_FILENAME)),	// jquery ui
 					self::LIB_JQUERY_UI_PLUS		=>	array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME)),	// jquery ui plus(追加分)
 					self::LIB_JQUERY_EASING			=>	array(	'script' => array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
-					self::LIB_JQUERY_JCAROUSEL		=>	array(	'script' => array(self::JQUERY_JCAROUSEL_FILENAME),// jquery.jcarousel用のファイル
-																'css'	=> array(self::JQUERY_JCAROUSEL_CSS)),
+					self::LIB_JQUERY_JCAROUSEL		=>	array(	'script' => array(self::JQUERY_JCAROUSEL_FILENAME)),// jquery.jcarousel用のファイル
 					self::LIB_JQUERY_THICKBOX		=>	array(	'script' => array(self::JQUERY_THICKBOX_FILENAME),// jquery.thickbox用のファイル
 																'css'	=> array(self::JQUERY_THICKBOX_CSS)),
 					self::LIB_JQUERY_JSHOTKEYS		=>	array(	'script' => array(self::JQUERY_JSHOTKEYS_FILENAME)),	// jquery.js-hotkeys用のファイル
