@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 2981 2010-03-29 09:38:42Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 3101 2010-05-07 06:02:10Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -670,6 +670,8 @@ class BaseFrameContainer extends Core
 					$curTemplate = $this->gSystem->defaultTemplateId();
 				} else if ($pageId == $this->gEnv->getDefaultMobilePageId()){		// 携帯サイトのとき
 					$curTemplate = $this->gSystem->defaultMobileTemplateId();		// 携帯用デフォルトテンプレート
+				} else if ($pageId == $this->gEnv->getDefaultSmartphonePageId()){		// スマートフォン用サイトのとき
+					$curTemplate = $this->gSystem->defaultSmartphoneTemplateId();		// スマートフォン用デフォルトテンプレート
 				} else if ($pageId == $this->gEnv->getDefaultAdminPageId() ||		// 管理サイトのとき
 							$pageId == $this->gEnv->getDefaultRegistPageId()){		// 登録サイトのとき
 					$curTemplate = '_admin';
@@ -681,7 +683,9 @@ class BaseFrameContainer extends Core
 			} else {
 				// テンプレートIDをセッションから取得
 				if ($this->gSystem->useTemplateIdInSession()){		// セッションに保存する場合
-					if (!$this->gEnv->getIsMobileSite()) $curTemplate = $request->getSessionValue(M3_SESSION_CURRENT_TEMPLATE);// 携帯サイトでないときはセッション値を取得
+					if (!$this->gEnv->getIsMobileSite() && !$this->gEnv->getIsSmartphoneSite()){
+						$curTemplate = $request->getSessionValue(M3_SESSION_CURRENT_TEMPLATE);// 携帯サイト、スマートフォンサイトでないときはセッション値を取得
+					}
 				}
 			}
 		}
@@ -690,6 +694,8 @@ class BaseFrameContainer extends Core
 		if ($curTemplate == ''){
 			if ($this->gEnv->getIsMobileSite()){// 携帯用サイトの場合
 				$curTemplate = $this->gSystem->defaultMobileTemplateId();		// 携帯用デフォルトテンプレート
+			} else if ($this->gEnv->getIsSmartphoneSite()){// スマートフォン用サイトの場合
+				$curTemplate = $this->gSystem->defaultSmartphoneTemplateId();		// スマートフォン用デフォルトテンプレート
 			} else {
 				$curTemplate = $this->gSystem->defaultTemplateId();
 			}
@@ -704,7 +710,7 @@ class BaseFrameContainer extends Core
 				if ($cmd == M3_REQUEST_CMD_SHOW_POSITION ||				// 表示位置を表示するとき
 					$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){	// 表示位置を表示するとき(ウィジェット付き)
 				} else {
-					if (!$this->gEnv->getIsMobileSite() && !$isSubclassDefined){		// PC用画面でサブクラス固定でないとき場合は保存
+					if (!$this->gEnv->getIsMobileSite() && !$this->gEnv->getIsSmartphoneSite() && !$isSubclassDefined){		// PC用画面でサブクラス固定でないとき場合は保存
 						$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $curTemplate);
 					}
 				}
@@ -723,11 +729,13 @@ class BaseFrameContainer extends Core
 		// サイトの公開状況を取得
 		$isOpen = $this->gSystem->siteInPublic();
 		if ($isOpen){
-			// PC用サイト、携帯用サイトの公開状況をチェック
+			// PC用サイト、携帯用サイト、スマートフォン用サイトの公開状況をチェック
 			if ($this->gEnv->getIsPcSite()){
 				if ($this->gSystem->sitePcInPublic()) return true;
 			} else if ($this->gEnv->getIsMobileSite()){
 				if ($this->gSystem->siteMobileInPublic()) return true;
+			} else if ($this->gEnv->getIsSmartphoneSite()){
+				if ($this->gSystem->siteSmartphoneInPublic()) return true;
 			}
 			return false;
 		} else {
