@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 3102 2010-05-07 06:05:36Z fishbone $
+ * @version    SVN: $Id: envManager.php 3160 2010-05-27 03:11:55Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -32,6 +32,7 @@ class EnvManager extends Core
 	private $defaultPageSubId;	// デフォルトのページサブId
 	private $currentWidgetPrefix;	// 現在作成中のウィジェットのプレフィックス文字列
 	private $currentWidgetTitle;	// 現在作成中のウィジェットのタイトル文字列
+	private $currentWidgetJoomlaParam;	// 現在作成中のウィジェットのJoomla用パラメータ
 	private $isCurrentWidgetShared;	// 現在作成中のウィジェットが共通ウィジェットかどうか
 	private $defaultLanguage;	// デフォルト言語(システムで固定)
 	private $currentLanguage;	// 現在の言語(ユーザによって可変)
@@ -1213,6 +1214,25 @@ class EnvManager extends Core
 	{
 		return $this->currentWidgetTitle;
 	}
+	/**
+	 * 現在作成中のウィジェットのJoomla用パラメータを設定
+	 *
+	 * @param array	$val	Joomla用パラメータ
+	 * @return		なし
+	 */
+	public function setCurrentWidgetJoomlaParam($val)
+	{
+		$this->currentWidgetJoomlaParam = $val;
+	}
+	/**
+	 * 現在作成中のウィジェットのJoomla用パラメータを取得
+	 *
+	 * @return array	Joomla用パラメータ
+	 */
+	public function getCurrentWidgetJoomlaParam()
+	{
+		return $this->currentWidgetJoomlaParam;
+	}
 	/**
 	 * 現在作成中のウィジェットが共通ウィジェットかどうかを設定
 	 *
