@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: instanceManager.php 2362 2009-09-26 14:44:38Z fishbone $
+ * @version    SVN: $Id: instanceManager.php 2660 2009-12-13 07:26:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -328,5 +328,20 @@ class InstanceManager extends Core
 		}
 		return $manager;
 	}
+	/**
+	 * サーバ接続マネージャー取得
+	 *
+	 * @return object			取得したオブジェクト
+	 */
+	static public function getConnectManager()
+	{
+		static $manager;// マネージャーオブジェクト
+		
+		if (!isset($manager)){
+			require_once(M3_SYSTEM_INCLUDE_PATH . '/manager/connectManager.php');
+			$manager 		= new ConnectManager();
+		}
+		return $manager;
+	}
 }
 ?>
