@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: JRender.php 2902 2010-03-07 06:27:19Z fishbone $
+ * @version    SVN: $Id: JRender.php 3163 2010-05-27 04:45:27Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($this->gEnv->getJoomlaRootPath() . '/JParameter.php');
@@ -72,7 +72,7 @@ class JRender
 		$params   = new JParameter();
 		if (isset($paramsOther['moduleclass_sfx'])) $params->set('moduleclass_sfx', $paramsOther['moduleclass_sfx']);
 		$chromeMethod = 'modChrome_' . $style;
-		
+
 		// Apply chrome and render module
 		if (function_exists($chromeMethod))
 		{
@@ -144,7 +144,8 @@ class JRender
 		$params->set('startLevel',		0);
 		$params->set('endLevel',		0);
 		$params->set('showAllChildren',	1);		// サブメニュー表示
-		
+		if (isset($paramsOther['moduleclass_sfx'])) $params->set('moduleclass_sfx', $paramsOther['moduleclass_sfx']);
+
 		// 必要なスクリプトを読み込む
 		$templateId = empty($this->templateId) ? $gEnvManager->getCurrentTemplateId() : $this->templateId;
 		$path = $gEnvManager->getTemplatesPath() . '/' . $templateId . '/html/mod_mainmenu/default.php';		// メニュー出力用スクリプト
@@ -157,7 +158,7 @@ class JRender
 
 			ob_clean();
 			require_once($gEnvManager->getJoomlaRootPath() . '/render/mainmenuHelper.php');		// デフォルトの出力方法
-			require_once($path);
+			require($path);		// 毎回実行する
 			$contents = ob_get_contents();
 			ob_clean();
 		}
