@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_ec.sql 1732 2009-04-13 02:32:14Z fishbone $
+-- * @version    SVN: $Id: create_ec.sql 2538 2009-11-10 08:24:57Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -552,8 +552,9 @@ CREATE TABLE product (
     pt_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
     pt_default_price     VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 優先する価格タイプ
     pt_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
-    pt_head_description  VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- HTMLヘッダ「description」
-    pt_head_keywords     VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- HTMLヘッダ「keywords」
+    pt_meta_title        TEXT                                         NOT NULL,      -- METAタグ、タイトル
+    pt_meta_description  TEXT                                         NOT NULL,      -- METAタグ、ページ要約
+    pt_meta_keywords     TEXT                                         NOT NULL,      -- METAタグ、検索用キーワード
     pt_search_keyword    VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 検索キーワード(「,」区切り)
     pt_site_url          TEXT                                         NOT NULL,      -- 詳細情報のサイト
     pt_unit_type_id      VARCHAR(4)     DEFAULT ''                    NOT NULL,      -- 販売の基準となる単位種別
