@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsystemBaseWidgetContainer.php 2844 2010-02-09 09:16:00Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsystemBaseWidgetContainer.php 3094 2010-05-03 10:33:20Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -19,6 +19,7 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 {
 	const HELP_KEY_CONFIGSYS = 'configsys';		// システム基本設定
 	const HELP_KEY_CONFIGLANG = 'configlang';		// 言語設定
+	const HELP_KEY_CONFIGMESSAGE = 'configmessage';		// メッセージ設定
 	const DEFAULT_TOP_PAGE = 'configsys';		// デフォルトのトップ画面
 	
 	/**
@@ -52,6 +53,9 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 			case 'configlang':	// 言語設定
 				$linkList = ' &gt;&gt; 言語設定';
 				break;
+			case 'configmessage':	// メッセージ設定
+				$linkList = ' &gt;&gt; メッセージ設定';
+				break;
 		}
 				
 		// ####### 上段メニューの作成 #######
@@ -72,7 +76,7 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 		$helpText = $this->gInstance->getHelpManager()->getHelpText(self::HELP_KEY_CONFIGSYS);
 		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>システム基本設定</span></a></li>' . M3_NL;
 		
-		// ### ページヘッダ情報 ###
+		// ### 言語設定 ###
 		$current = '';
 		$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=configlang';
 		if ($task == 'configlang'){
@@ -82,6 +86,16 @@ class admin_mainConfigsystemBaseWidgetContainer extends admin_mainBaseWidgetCont
 		$helpText = $this->gInstance->getHelpManager()->getHelpText(self::HELP_KEY_CONFIGLANG);
 		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>言語設定</span></a></li>' . M3_NL;
 		
+		// ### メッセージ設定 ###
+		$current = '';
+		$link = $this->gEnv->getDefaultAdminUrl() . '?' . 'task=configmessage';
+		if ($task == 'configmessage'){
+			$current = 'id="current"';
+		}
+		// ヘルプを作成
+		$helpText = $this->gInstance->getHelpManager()->getHelpText(self::HELP_KEY_CONFIGMESSAGE);
+		$menuText .= '<li ' . $current . '><a href="'. $this->getUrl($link) .'"><span ' . $helpText . '>メッセージ設定</span></a></li>' . M3_NL;
+		
 		// 上段メニュー終了
 		$menuText .= '</ul>' . M3_NL;
 		$menuText .= '</div>' . M3_NL;
