@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 3061 2010-04-23 13:05:11Z fishbone $
+ * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 3100 2010-05-07 06:00:57Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -58,8 +58,8 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 			return 'pagedef_detail.tmpl.html';
 		} else if ($task == 'pagedef_mobile'){		// 携帯用設定画面
 			return 'pagedef_mobile.tmpl.html';
-		} else if ($task == 'pagedef_smart'){		// スマートフォン用設定画面
-			return 'pagedef_smart.tmpl.html';
+		} else if ($task == 'pagedef_smartphone'){		// スマートフォン用設定画面
+			return 'pagedef_smartphone.tmpl.html';
 		} else {			// 画面定義画面
 			return 'pagedef.tmpl.html';
 		}
@@ -99,10 +99,16 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		$this->pageId = $request->trimValueOf('pageid');		// ページID
 		$this->pageSubId = $request->trimValueOf('pagesubid');// ページサブID
 		if (empty($this->pageId)){
-			if ($task == 'pagedef_mobile'){		// 携帯用設定画面のとき
-				$this->pageId = $this->gEnv->getDefaultMobilePageId();				// 携帯用デフォルト値取得
-			} else {			// PC用画面のとき
-				$this->pageId = $this->gEnv->getDefaultPageId();				// デフォルト値取得
+			switch ($task){
+				case 'pagedef_mobile':		// 携帯用設定画面のとき
+					$this->pageId = $this->gEnv->getDefaultMobilePageId();				// 携帯用デフォルト値取得
+					break;
+				case 'pagedef_smartphone':		// スマートフォン用設定画面のとき
+					$this->pageId = $this->gEnv->getDefaultSmartphonePageId();				// スマートフォン用デフォルト値取得
+					break;
+				default:						// PC用画面のとき
+					$this->pageId = $this->gEnv->getDefaultPageId();				// デフォルト値取得
+					break;
 			}
 		}
 		if (empty($this->pageSubId)) $this->pageSubId = $this->gEnv->getDefaultPageSubIdByPageId($this->pageId);// デフォルト値取得
@@ -110,14 +116,19 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		if ($act == 'changetemplate'){		// テンプレート変更のとき
 			$templateId = $request->trimValueOf('sel_template');		// テンプレートID
 			if (!empty($templateId)){
-				if ($task == 'pagedef_mobile'){		// 携帯用設定画面のとき
-					$this->gSystem->changeDefaultMobileTemplate($templateId);
-				} else if ($task == 'pagedef_smart'){		// スマートフォン用設定画面
-				} else {
-					$this->gSystem->changeDefaultTemplate($templateId);
+				switch ($task){
+					case 'pagedef_mobile':		// 携帯用設定画面のとき
+						$this->gSystem->changeDefaultMobileTemplate($templateId);
+						break;
+					case 'pagedef_smartphone':		// スマートフォン用設定画面のとき
+						$this->gSystem->changeDefaultSmartphoneTemplate($templateId);
+						break;
+					default:						// PC用画面のとき
+						$this->gSystem->changeDefaultTemplate($templateId);
 			
-					// セッションのテンプレートIDを更新
-					$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
+						// セッションのテンプレートIDを更新
+						$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
+						break;
 				}
 				// キャッシュデータをクリア
 				$this->gCache->clearAllCache();
@@ -135,17 +146,17 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 			
 			// テンプレート選択メニュー作成
 			$this->db->getAllTemplateList(1/* 携帯用 */, array($this, 'templateIdLoop'));
-		} else if ($task == 'pagedef_smart'){		// スマートフォン用設定画面
+		} else if ($task == 'pagedef_smartphone'){		// スマートフォン用設定画面
 			// ページメインIDメニュー作成
-			$this->db->getPageIdList(array($this, 'pageIdLoop'), 0/*ページID*/, 1/*携帯*/);
+			$this->db->getPageIdList(array($this, 'pageIdLoop'), 0/*ページID*/, 2/*スマートフォン*/);
 		
 			// デフォルトのテンプレートを取得
-			$this->templateId = $this->gSystem->defaultMobileTemplateId();
+			$this->templateId = $this->gSystem->defaultSmartphoneTemplateId();
 			$imagePath = $this->gEnv->getTemplatesUrl() . '/' . $this->templateId . '/template_thumbnail.png';
 			$this->tmpl->addVar("_widget", "TMPL_IMAGE", $this->getUrl($imagePath));							// プレビュー画像
 			
 			// テンプレート選択メニュー作成
-			$this->db->getAllTemplateList(1/* 携帯用 */, array($this, 'templateIdLoop'));
+			$this->db->getAllTemplateList(2/* スマートフォン用 */, array($this, 'templateIdLoop'));
 		} else {			// PC用設定画面のとき
 			// ページメインIDメニュー作成
 			$this->db->getPageIdList(array($this, 'pageIdLoop'), 0/*ページID*/, 0/*携帯以外*/);
@@ -175,7 +186,6 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		for ($i = 0; $i < count($pathArray); $i++){
 			$path .= '/' . $pathArray[$i];
 		}
-		//$url = $this->gEnv->getRootUrl() . $path . '.php';
 		$url = $this->gEnv->getRootUrlByPage($this->pageId, $this->pageSubId) . $path . '.php';
 		if ($this->pageSubId == $this->defaultPageSubId){
 			$urlWithSession = $url . '?' . $this->gAccess->getSessionIdUrlParam();		// セッションIDをURLに追加
@@ -474,86 +484,5 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		$this->tmpl->parseTemplate('position_list', 'a');
 		return true;
 	}
-	/**
-	 * ウィジェットリスト、取得したデータをテンプレートに設定する
-	 *
-	 * @param int $index			行番号(0～)
-	 * @param array $fetchedRow		フェッチ取得した行
-	 * @param object $param			未使用
-	 * @return bool					true=処理続行の場合、false=処理終了の場合
-	 */
-	/*function widgetListLoop($index, $fetchedRow, $param)
-	{
-		$hasScript = '';
-		if ($fetchedRow['wd_read_scripts']){
-			$hasScript = 'checked';
-		}
-		$hasCss = '';
-		if ($fetchedRow['wd_read_css']){
-			$hasCss = 'checked';
-		}
-		$hasAdmin = '0';
-		if ($fetchedRow['wd_has_admin']){
-			$hasAdmin = '1';
-		}
-		// 編集不可項目のときは、ボタンを使用不可にする
-		$buttonEnabled = '';
-		if (!$fetchedRow['wd_editable']) $buttonEnabled = 'disabled';
-		
-		// 管理画面がないときは、詳細ボタンを使用不可にする
-		$detailButtonEnabled = '';
-		if (!$fetchedRow['wd_has_admin']) $detailButtonEnabled = 'disabled';
-		
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
-		
-		// 新規に追加されたウィジェットかチェック
-		$id = $this->convertToDispString($fetchedRow['wd_id']);
-		$idText = $id;
-		for ($i = 0; $i < count($this->newWidget); $i++){
-			if ($this->newWidget[$i] == $id){
-				$idText = '<b><font color="green">' . $id . '</font></b>';
-				break;
-			}
-		}
-		
-		// ウィジェット名
-		$name = $this->convertToDispString($fetchedRow['wd_name']);
-		
-		// ウィジェットの画像を設定
-		$image = $this->gDesign->getWidgetIconUrl($id, self::DEFAULT_IMAGE_SIZE);
-		$imageTag = '<img class="widget_obj" src="' . $this->getUrl($image) . '" ';
-		$imageTag .= 'width="' . self::DEFAULT_IMAGE_SIZE . '"';
-		$imageTag .= ' height="' . self::DEFAULT_IMAGE_SIZE . '"';
-		$imageTag .= ' />';
-		
-		$message = '<b>' . $name . '</b><br>' . $id;
-		$imageTag = '<span class="tooltip_text" href="#" >' . $imageTag . '</span>';
-		
-		// ウィジェットの説明の作成
-		//$tipText = $this->gInstance->getHelpManager()->createTipText($name, $this->convertToDispString($fetchedRow['wd_description']));
-
-		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
-			'no' => $index + 1,													// 行番号
-			'serial' => $this->convertToDispString($fetchedRow['wd_serial']),			// シリアル番号
-			'id' => $id,			// ID
-			'widget_id' => 'widget_' . $id,
-			'widget_name'		=> $this->convertToDispString($fetchedRow['wd_name']),				// ウィジェット名
-			'id_text' => $idText,
-			'name' => $name,		// 名前
-			'image_tag' => $imageTag,		// 画像
-			'tip' => $tipText				// 説明文字列
-		);
-		$this->tmpl->addVars('widgetlist', $row);
-		$this->tmpl->parseTemplate('widgetlist', 'a');
-		
-		$this->widgetArray[] = $id;
-		return true;
-	}
-	*/
 }
 ?>
