@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPageinfoWidgetContainer.php 2732 2009-12-24 01:31:40Z fishbone $
+ * @version    SVN: $Id: admin_mainPageinfoWidgetContainer.php 2876 2010-02-23 10:44:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainMasterBaseWidgetContainer.php');
@@ -108,7 +108,7 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 		$this->defaultSubId = $this->sysDb->getDefaultPageSubId($this->pageId);
 		
 		// ページサブID一覧を作成
-		$this->db->getPageSubIdList($this->pageId, array($this, 'pageSubIdLoop'));
+		$this->db->getPageSubIdList($this->pageId, ''/*言語なし*/, array($this, 'pageSubIdLoop'));
 		
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 	}
