@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 3100 2010-05-07 06:00:57Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 3131 2010-05-14 07:07:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -211,7 +211,7 @@ class admin_mainDb extends BaseDb
 	 * @param function $callback	コールバック関数
 	 * @return						なし
 	 */
-	function getAvailableWidgetList($callback)
+	/*function getAvailableWidgetList($callback)
 	{
 		$queryStr  = 'select * from _widgets ';
 		$queryStr .=   'where wd_deleted = false ';// 削除されていない
@@ -219,14 +219,14 @@ class admin_mainDb extends BaseDb
 		$queryStr .=     'and wd_mobile = false ';		// 携帯用ウィジェット以外
 		$queryStr .=   'order by wd_id';
 		$this->selectLoop($queryStr, array(), $callback);
-	}
+	}*/
 	/**
 	 * 携帯用のウィジェットリスト(メニューから選択可能なもの)取得
 	 *
 	 * @param function $callback	コールバック関数
 	 * @return						なし
 	 */
-	function getAvailableMobileWidgetList($callback)
+	/*function getAvailableMobileWidgetList($callback)
 	{
 		$queryStr  = 'select * from _widgets ';
 		$queryStr .=   'where wd_deleted = false ';// 削除されていない
@@ -234,7 +234,7 @@ class admin_mainDb extends BaseDb
 		$queryStr .=     'and wd_mobile = true ';		// 携帯用ウィジェット
 		$queryStr .=   'order by wd_id';
 		$this->selectLoop($queryStr, array(), $callback);
-	}
+	}*/
 	/**
 	 * ウィジェットIDリスト取得
 	 *
@@ -2337,13 +2337,13 @@ class admin_mainDb extends BaseDb
 	/**
 	 * コンテンツ項目一覧を取得
 	 *
-	 * @param function	$callback			コールバック関数
 	 * @param string	$lang				言語
+	 * @param string	$contentType		コンテンツタイプ
+	 * @param function	$callback			コールバック関数
 	 * @return 			なし
 	 */
-	function getVisibleAllContents($callback, $lang)
+	function getVisibleAllContents($lang, $contentType, $callback)
 	{
-		$contentType = '';
 		$queryStr = 'SELECT * FROM content ';
 		$queryStr .=  'WHERE cn_type = ? ';
 		$queryStr .=    'AND cn_language_id = ? ';
