@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 2780 2010-01-15 05:36:30Z fishbone $
+ * @version    SVN: $Id: index.php 2846 2010-02-10 06:12:59Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -40,11 +40,25 @@ $HELP['configsite_keywords']['title'] = '検索キーワード';
 $HELP['configsite_keywords']['body'] = 'ヘッダ部のkeywordsタグに設定される文字列です。検索エンジン用のキーワードを「,」区切りで10個以下で記述します。';
 
 // ########## システム情報 ##########
+$HELP['configsys']['title'] = 'システム基本設定';
+$HELP['configsys']['body'] = 'システムの動作に関する基本設定を行います。';
 $HELP['configsys_ssl_url']['title'] = '共有SSLのルートURL';
 $HELP['configsys_ssl_url']['body'] = '管理画面または一般画面でSSLを使用する場合にSSL専用の別のURLが設定可能です。空に設定した場合はシステムのルートURLをhttpsに変更したURLが使用されます。';
 $HELP['configsys_connect_server_url']['title'] = 'ポータルサーバのURL';
 $HELP['configsys_connect_server_url']['body'] = 'ポータルサーバに接続する場合の接続先URLです。Magic3がインストールされているURLを指定します。';
 
+// ########## 言語設定 ##########
+$HELP['configlang']['title'] = '言語設定';
+$HELP['configlang']['body'] = '言語に関する設定を行います。';
+$HELP['configlang_list']['title'] = 'アクセス可能言語';
+$HELP['configlang_list']['body'] = 'アクセス可能な言語を設定します。';
+$HELP['configlang_name']['title'] = '言語';
+$HELP['configlang_name']['body'] = '言語名です。';
+$HELP['configlang_value']['title'] = '値';
+$HELP['configlang_value']['body'] = '識別用の値です。';
+$HELP['configlang_accept']['title'] = '許可';
+$HELP['configlang_accept']['body'] = 'アクセス可能な言語にチェックを入れます。';
+
 // ########## ユーザ一覧 ##########
 $HELP['userlist']['title'] = 'ユーザ一覧';
 $HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧です。';
