@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: bbs_2ch_mainReadWidgetContainer.php 2802 2010-01-23 01:22:05Z fishbone $
+ * @version    SVN: $Id: bbs_2ch_mainReadWidgetContainer.php 2816 2010-01-29 05:56:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/bbs_2ch_mainBaseWidgetContainer.php');
@@ -20,8 +20,8 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 	private $threadStyle;	// スレッド部表示スタイル
 	private $subjectColor;	// 件名文字色
 	private $nameColor;		// 登録者名文字色
-	private $autolink;		// リンクを自動作成
 	private $createEmailLink;	// Eメールのリンクを作成するかどうか
+	private $isExistsMessage;	// メッセージが存在するかどうか
 	
 	/**
 	 * コンストラクタ
@@ -57,8 +57,9 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		$act = $request->trimValueOf('act');
-		$threadId = $request->valueOf(M3_REQUEST_PARAM_BBS_THREAD_ID);	// スレッドID
-		$list = $request->valueOf(M3_REQUEST_PARAM_LIST_NO);			// 取得メッセージ
+		$threadId = $request->trimValueOf(M3_REQUEST_PARAM_BBS_THREAD_ID);	// スレッドID
+		$list = $request->trimValueOf(M3_REQUEST_PARAM_LIST_NO);			// 取得メッセージ
+		$no = intval($request->trimValueOf(M3_REQUEST_PARAM_ITEM_NO));				// 取得メッセージ
 		$message = $request->valueOf('bbs_message');// 投稿メッセージ
 		$name = $request->trimValueOf('bbs_name');// 名前
 		$email = $request->trimValueOf('bbs_email');// Eメールアドレス
@@ -90,7 +91,6 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 		}
 		
 		// 表示スタイル作成
-		$this->autolink = $this->_configArray[self::CF_AUTOLINK];		// リンクを自動作成
 		$this->createEmailLink = $this->_configArray[self::CF_SHOW_EMAIL];		// Eメールのリンクを作成するかどうか
 		$threadColor = $this->_configArray[self::CF_THREAD_COLOR];		// スレッド表示部背景色
 		$this->threadStyle .= 'background-color:' . $threadColor . ';';
@@ -104,12 +104,18 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 			$limit = 0;		// 取得数、すべて取得
 			
 			// 表示範囲を取得
-			if (strStartsWith($list, 'l')){		// 最新から取得の場合
-				$messageCount = intval(substr($list, 1));
-				if ($messageCount <= 0) $messageCount = 1;
-				$offset = $row['th_message_count'] - $messageCount;
+			if (empty($list) && !empty($no)){		// メッセージNoで取得のとき
+				$offset = $no -1;
 				if ($offset < 0) $offset = 0;
-				$limit = $messageCount;
+				$limit = 1;
+			} else {		// 一覧で取得のとき
+				if (strStartsWith($list, 'l')){		// 最新から取得の場合
+					$messageCount = intval(substr($list, 1));
+					if ($messageCount <= 0) $messageCount = 1;
+					$offset = $row['th_message_count'] - $messageCount;
+					if ($offset < 0) $offset = 0;
+					$limit = $messageCount;
+				}
 			}
 			// 投稿文を作成
 			$this->_db->getThreadMessageByRange(array($this, 'itemsLoop'), $this->_boardId, $threadId, $limit, $offset);
@@ -131,6 +137,13 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 			$this->tmpl->addVar("thread_area", "thread_id", $threadId);
 			$this->tmpl->addVar("thread_area", "subject", $this->convertToDispString($row['th_subject']));				// スレッド件名
 			$this->tmpl->addVar("thread_area", "subject_color", $this->subjectColor);		// 件名表示色
+			
+			// スレッドが存在しないときはタグを非表示にする
+			if (!$this->isExistsMessage){
+				$this->setUserErrorMsg('ＥＲＲＯＲ：メッセージが存在しません！');
+				
+				$this->tmpl->setAttribute('message_list', 'visibility', 'hidden');
+			}
 		} else {
 			$this->setUserErrorMsg('ＥＲＲＯＲ：スレッドＩＤが不正です！');
 			
@@ -175,8 +188,8 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 		$message = $this->convertToPreviewText($message);			// 改行をBRタグに変換
 		if ($fetchedRow['te_index'] == 1) $message .= '<br />';		// トップのメッセージは改行を追加
 		
-		// リンク変換
-		if (!empty($this->autolink)) $message = preg_replace("/(https?):\/\/([\w;\/\?:\@&=\+\$,\-\.!~\*'\(\)%#]+)/", "<a href=\"$1://$2\" target=\"_blank\">$1://$2</a>", $message);
+		// メッセージ変換
+		$message = $this->convDispMessage($message, $fetchedRow['te_thread_id']);
 		
 		// 削除メッセージのとき
 		if ($fetchedRow['te_deleted']){
@@ -192,6 +205,9 @@ class bbs_2ch_mainReadWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 		);
 		$this->tmpl->addVars('message_list', $row);
 		$this->tmpl->parseTemplate('message_list', 'a');
+		
+		// メッセージが存在するかどうか
+		$this->isExistsMessage = true;
 		return true;
 	}
 }
