@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: breadcrumbDb.php 2892 2010-03-06 01:01:55Z fishbone $
+ * @version    SVN: $Id: breadcrumbDb.php 2961 2010-03-23 10:13:29Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -73,7 +73,7 @@ class breadcrumbDb extends BaseDb
 		$queryStr .=  'FROM _menu_def ';
 		$queryStr .=  'WHERE md_menu_id in (' . $menuId . ') ';
 		$queryStr .=  'ORDER BY no, md_index';
-		$retValue = $this->selectRecords($queryStr, array($menuId), $rows);
+		$retValue = $this->selectRecords($queryStr, array(), $rows);
 		return $retValue;
 	}
 	/**
