@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuWidgetContainer.php 2553 2009-11-14 11:32:06Z fishbone $
+ * @version    SVN: $Id: default_menuWidgetContainer.php 3164 2010-05-27 05:11:47Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -84,7 +84,11 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 			$name		= $targetObj->name;// 定義名
 			$this->isHierMenu	= $targetObj->isHierMenu;		// 階層化メニューを使用するかどうか
 			$limitUser	= $targetObj->limitUser;// ユーザを制限するかどうか
+			$useVerticalMenu = $targetObj->useVerticalMenu;		// 縦型メニューデザインを使用するかどうか
 			
+			// 縦型メニューデザイン使用の場合はJoomla用パラメータを設定
+			if (!empty($useVerticalMenu)) $this->gEnv->setCurrentWidgetJoomlaParam(array('moduleclass_sfx' => 'art-vmenu'));
+
 			// ユーザ制限があるときはログイン時のみ表示
 			if (!$limitUser || $this->gEnv->isCurrentUserLogined()){
 				// メニュー作成
